@@ -2,7 +2,7 @@ from inspect import getargspec
 from functools import wraps
 
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 
 class SchemaError(Exception):
@@ -47,11 +47,12 @@ class And(object):
 class Or(And):
 
     def validate(self, data):
+        x = None
         for s in [Schema(s, error=self._error) for s in self._args]:
             try:
                 return s.validate(data)
-            except SchemaError as x:
-                pass
+            except SchemaError as _x:
+                x = _x
         raise SchemaError(['%r did not validate %r' % (self, data)] + x.autos,
                          [self._error] + x.errors)
 
@@ -104,7 +105,8 @@ class Schema(object):
                         nkey = Schema(skey, error=e).validate(key)
                         try:
                             nvalue = Schema(svalue, error=e).validate(value)
-                        except SchemaError as x:
+                        except SchemaError as _x:
+                            x = _x
                             raise
                     except SchemaError:
                         pass
@@ -160,32 +162,3 @@ class Schema(object):
 class Optional(Schema):
 
     """Marker for an optional part of Schema."""
-
-
-def _guard(*schemas, **kwschema):
-    """Experimental code."""
-    def decorator(oldf):
-        spec = getargspec(oldf)
-        @wraps(oldf)
-        def newf(*args, **kw):
-        #make_env = eval('lambda %s: locals()' % formatargspec(*spec)[1:][:-1])
-        #env = make_env(*args, **kw)
-            env = dict(zip(reversed(spec.args), reversed(spec.defaults or ()))
-                     + zip(spec.args, args)
-                     + [(k, v) for k, v in kw.items() if k in spec.args])
-            if spec.varargs is not None:
-                env[spec.varargs] = args[len(spec.args):]
-            if spec.keywords is not None:
-                env[spec.keywords] = dict((k, v) for k, v in kw.items()
-                                          if k not in spec.args)
-            senv = dict(zip(spec.args, schemas) + kwschema.items())
-            venv = Schema(senv).validate(env)
-            nargs = tuple(venv[k] for k in spec.args)
-            if spec.varargs is not None:
-                nargs += venv[spec.varargs]
-            nkw = dict((venv[spec.keywords].items() if spec.keywords else [])
-                    + [(k, v) for k, v in venv.items() if k not in
-                       tuple(spec.args) + (spec.varargs, spec.keywords)])
-            return oldf(*nargs, **nkw)
-        return newf
-    return decorator
